gnumake_tokenpool: Jobclient and jobserver for the GNU make tokenpool protocol
==============================================================================

Description
-----------

The project has implementations in multiple languages.

We only install the implementation in Python.


License
-------

MIT


Upstream Contact
----------------

- https://github.com/milahu/gnumake-tokenpool (upstream)
